Enum sdl2_sys::log::SDL_LOG_CATEGORY
[−]
[src]
#[repr(u32)]pub enum SDL_LOG_CATEGORY { APPLICATION, ERROR, ASSERT, SYSTEM, AUDIO, VIDEO, RENDER, INPUT, TEST, RESERVED1, RESERVED2, RESERVED3, RESERVED4, RESERVED5, RESERVED6, RESERVED7, RESERVED8, RESERVED9, RESERVED10, CUSTOM, }
\brief The predefined log categories
By default the application category is enabled at the INFO level, the assert category is enabled at the WARN level, test is enabled at the VERBOSE level and all other categories are enabled at the CRITICAL level.
Variants
APPLICATIONERRORASSERTSYSTEMAUDIOVIDEORENDERINPUTTESTRESERVED1RESERVED2RESERVED3RESERVED4RESERVED5RESERVED6RESERVED7RESERVED8RESERVED9RESERVED10CUSTOMTrait Implementations
impl Debug for SDL_LOG_CATEGORY[src]
impl Copy for SDL_LOG_CATEGORY[src]
impl Clone for SDL_LOG_CATEGORY[src]
fn clone(&self) -> SDL_LOG_CATEGORY
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for SDL_LOG_CATEGORY[src]
fn eq(&self, __arg_0: &SDL_LOG_CATEGORY) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.